datapoints
==========
.. automodule:: prem.resources.datapoints.resource
   :members: DataPoints
   :undoc-members:
   :show-inheritance:

models
------

.. autoclass:: prem.resources.datapoints.models.DataPoint
   :members:
   :undoc-members:

.. autoclass:: prem.resources.datapoints.models.PatchedDataPoint
   :members:
   :undoc-members:
